@@ -23,7 +23,7 @@ import re
 
 import gtk
 
-import ElementTree as et
+import xml.etree.ElementTree as et
 from Helper import *
 
 class NamespacedId:
@@ -176,7 +176,7 @@ class SnippetData:
 
         def _create_xml(self, parent=None, update=False, attrib={}):
                 # Create a new node
-                if parent:
+                if parent != None:
                         element = et.SubElement(parent, 'snippet', attrib)
                 else:
                         element = et.Element('snippet')
@@ -660,8 +660,12 @@ class Library(Singleton):
                 self._accelerator_activated_cb = cb
         
         def accelerator_activated(self, group, obj, keyval, mod):
+                ret = False
+
                 if self._accelerator_activated_cb:
-                        self._accelerator_activated_cb(group, obj, keyval, mod)
+                        ret = self._accelerator_activated_cb(group, obj, keyval, mod)
+
+                return ret
 
         def add_snippet(self, library, element):
                 container = self.container(library.language)
@@ -854,8 +858,9 @@ class Library(Singleton):
                 
         def get_accel_group(self, language):
                 language = self.normalize_language(language)
-                
                 container = self.container(language)
+
+                self.ensure(language)
                 return container.accel_group
                 
         def save(self, language):
